# lingo - payment and billing system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.urls import path

from . import views

urlpatterns = [
    path('', views.home, name='lingo-manager-invoicing-home'),
    path('regies/', views.regies_list, name='lingo-manager-invoicing-regie-list'),
    path(
        'regie/add/',
        views.regie_add,
        name='lingo-manager-invoicing-regie-add',
    ),
    path(
        'regie/<int:pk>/',
        views.regie_detail,
        name='lingo-manager-invoicing-regie-detail',
    ),
    path(
        'regie/<int:pk>/edit/',
        views.regie_edit,
        name='lingo-manager-invoicing-regie-edit',
    ),
    path(
        'regie/<int:pk>/delete/',
        views.regie_delete,
        name='lingo-manager-invoicing-regie-delete',
    ),
    path('regies/import/', views.regies_import, name='lingo-manager-invoicing-regie-import'),
    path('regies/export/', views.regies_export, name='lingo-manager-invoicing-regie-export'),
    path(
        'regie/<int:regie_pk>/campaign/add/',
        views.campaign_add,
        name='lingo-manager-invoicing-campaign-add',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/',
        views.campaign_detail,
        name='lingo-manager-invoicing-campaign-detail',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/edit/',
        views.campaign_edit,
        name='lingo-manager-invoicing-campaign-edit',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/dates/edit/',
        views.campaign_dates_edit,
        name='lingo-manager-invoicing-campaign-dates-edit',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/delete/',
        views.campaign_delete,
        name='lingo-manager-invoicing-campaign-delete',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/unlock-check/',
        views.campaign_unlock_check,
        name='lingo-manager-invoicing-campaign-unlock-check',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/finalize/',
        views.campaign_finalize,
        name='lingo-manager-invoicing-campaign-finalize',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/pool/add/',
        views.pool_add,
        name='lingo-manager-invoicing-pool-add',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/',
        views.pool_detail,
        name='lingo-manager-invoicing-pool-detail',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/journal/',
        views.pool_journal,
        name='lingo-manager-invoicing-pool-journal',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/promote/',
        views.pool_promote,
        name='lingo-manager-invoicing-pool-promote',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/delete/',
        views.pool_delete,
        name='lingo-manager-invoicing-pool-delete',
    ),
    path(
        'regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/invoice/<int:invoice_pk>/pdf/',
        views.invoice_pdf,
        name='lingo-manager-invoicing-invoice-pdf',
    ),
    path(
        'ajax/regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/invoice/<int:invoice_pk>/lines/',
        views.invoice_line_list,
        name='lingo-manager-invoicing-invoice-line-list',
    ),
    path(
        'ajax/regie/<int:regie_pk>/campaign/<int:pk>/pool/<int:pool_pk>/line/<int:line_pk>/<slug:status>/',
        views.line_set_error_status,
        name='lingo-manager-invoicing-line-set-error-status',
    ),
    path(
        'regie/<int:regie_pk>/non-invoiced-lines/',
        views.non_invoiced_line_list,
        name='lingo-manager-invoicing-non-invoiced-line-list',
    ),
    path(
        'regie/<int:regie_pk>/invoices/',
        views.regie_invoice_list,
        name='lingo-manager-invoicing-regie-invoice-list',
    ),
    path(
        'regie/<int:regie_pk>/invoice/<int:invoice_pk>/pdf/',
        views.regie_invoice_pdf,
        name='lingo-manager-invoicing-regie-invoice-pdf',
    ),
    path(
        'ajax/regie/<int:regie_pk>/invoice/<int:invoice_pk>/lines/',
        views.regie_invoice_line_list,
        name='lingo-manager-invoicing-regie-invoice-line-list',
    ),
]
